/**
 * compat_endian.h
 * Copyright (C) 2013 Jan Viktorin
 */

#ifndef COMPAT_ENDIAN_H
#define COMPAT_ENDIAN_H

#ifdef __MICROBLAZEEL__

#include <inttypes.h>
#include <arpa/inet.h>

static inline uint32_t native_to_le(const uint32_t v) {return v;}
static inline uint32_t native_to_be(const uint32_t v) {return htonl(v);}

static inline uint32_t le_to_native(const uint32_t v) {return v;}
static inline uint32_t be_to_native(const uint32_t v) {return ntohl(v);}

static inline uint16_t native_to_le16(const uint16_t v) {return v;}
static inline uint16_t native_to_be16(const uint16_t v) {return htons(v);}

static inline uint16_t le_to_native16(const uint16_t v) {return v;}
static inline uint16_t be_to_native16(const uint16_t v) {return ntohs(v);}

#else

#define _BSD_SOURCE
#include <endian.h>
#include <inttypes.h>
#include <byteswap.h>

#if BYTE_ORDER == BIG_ENDIAN

static inline uint32_t native_to_le(const uint32_t v) {return bswap_32(v);}
static inline uint32_t native_to_be(const uint32_t v) {return v;}

static inline uint32_t le_to_native(const uint32_t v) {return bswap_32(v);}
static inline uint32_t be_to_native(const uint32_t v) {return v;}

static inline uint16_t native_to_le16(const uint16_t v) {return bswap_16(v);}
static inline uint16_t native_to_be16(const uint16_t v) {return v;}

static inline uint16_t le_to_native16(const uint16_t v) {return bswap_16(v);}
static inline uint16_t be_to_native16(const uint16_t v) {return v;}

#elif BYTE_ORDER == LITTLE_ENDIAN

static inline uint32_t native_to_le(const uint32_t v) {return v;}
static inline uint32_t native_to_be(const uint32_t v) {return bswap_32(v);}

static inline uint32_t le_to_native(const uint32_t v) {return v;}
static inline uint32_t be_to_native(const uint32_t v) {return bswap_32(v);}

static inline uint16_t native_to_le16(const uint16_t v) {return v;}
static inline uint16_t native_to_be16(const uint16_t v) {return bswap_16(v);}

static inline uint16_t le_to_native16(const uint16_t v) {return v;}
static inline uint16_t be_to_native16(const uint16_t v) {return bswap_16(v);}

#endif

#endif

static inline
uint32_t le_to_be(const uint32_t v) { return native_to_be(le_to_native(v)); }

static inline
uint32_t be_to_le(const uint32_t v) { return native_to_le(be_to_native(v)); }

static inline
uint16_t le_to_be16(const uint16_t v) { return native_to_be16(le_to_native16(v)); }

static inline
uint16_t be_to_le16(const uint16_t v) { return native_to_le16(be_to_native16(v)); }

#endif

