/**
 * test_compat_endian.c
 * Copyright (C) 2013 Jan Viktorin
 */

#define _BSD_SOURCE
#include "compat_endian.h"
#include "cccid_test.h"
#include <endian.h>

static void assert_equal(uint32_t orig, uint32_t computed, uint32_t expected, const char *op)
{
	if(computed != expected)
		test_failed("%s(0x%08x) == 0x%08x != 0x%08x", op, orig, computed, expected);

	test_ok("%s(0x%08x) == 0x%08x == 0x%08x", op, orig, computed, expected);
}

int main(int argc, char **argv)
{
	assert_equal(0x01020304, le_to_be(0x01020304), 0x04030201, "le_to_be");
	assert_equal(0x01020304, be_to_le(0x01020304), 0x04030201, "be_to_le");
	assert_equal(2097152000, le_to_be(2097152000), 125, "le_to_be");
	assert_equal(125, be_to_le(125), 2097152000, "be_to_le");
	assert_equal(2080374784, le_to_be(2080374784), 124, "le_to_be");
	assert_equal(124, be_to_le(124), 2080374784, "be_to_le");

	#if BYTE_ORDER == LITTLE_ENDIAN
	assert_equal(0x01020304, le_to_native(0x01020304), 0x01020304, "[l]le_to_native");
	assert_equal(0x01020304, be_to_native(0x01020304), 0x04030201, "[l]be_to_native");
	assert_equal(0x01020304, native_to_le(0x01020304), 0x01020304, "[l]native_to_le");
	assert_equal(0x01020304, native_to_be(0x01020304), 0x04030201, "[l]native_to_be");
	#elif BYTE_ORDER == BIG_ENDIAN
	assert_equal(0x01020304, be_to_native(0x01020304), 0x01020304, "[b]be_to_native");
	assert_equal(0x01020304, le_to_native(0x01020304), 0x04030201, "[b]le_to_native");
	assert_equal(0x01020304, native_to_be(0x01020304), 0x01020304, "[b]native_to_be");
	assert_equal(0x01020304, native_to_le(0x01020304), 0x04030201, "[b]native_to_le");
	#endif

	return 0;
}
